==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ga-IE/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Tá cuntas leis an ríomhphost seo ann cheana féin.',
    'account_not_found'      => 'Tá an t-ainm úsáideora nó an focal faire mícheart.',
    'account_not_activated'  => 'Níl an cuntas úsáideora seo curtha i ngníomh.',
    'account_suspended'      => 'Tá an cuntas úsáideora seo ar fionraí.',
    'account_banned'         => 'Tá toirmeasc ar an gcuntas úsáideora seo.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Rinne tú logáil isteach go rathúil.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh logáil isteach, déan iarracht arís.',
        'success' => 'Rinne tú logáil isteach go rathúil.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh do chuntas a chruthú, déan iarracht arís.',
        'success' => 'Cruthaigh an cuntas go rathúil.',
    ),

    'forgot-password' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh cód pasfhocal a athshocrú, déan iarracht arís.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh an focal faire a athshocrú, déan iarracht arís.',
        'success' => 'D\'athshocraigh do phasfhocal go rathúil.',
    ),


);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ga-IE/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Tá cuntas leis an ríomhphost seo ann cheana féin.',
    'account_not_found'      => 'Tá an t-ainm úsáideora nó an focal faire mícheart.',
    'account_not_activated'  => 'Níl an cuntas úsáideora seo curtha i ngníomh.',
    'account_suspended'      => 'Tá an cuntas úsáideora seo ar fionraí.',
    'account_banned'         => 'Tá toirmeasc ar an gcuntas úsáideora seo.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Rinne tú logáil isteach go rathúil.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh logáil isteach, déan iarracht arís.',
        'success' => 'Rinne tú logáil isteach go rathúil.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh do chuntas a chruthú, déan iarracht arís.',
        'success' => 'Cruthaigh an cuntas go rathúil.',
    ),

    'forgot-password' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh cód pasfhocal a athshocrú, déan iarracht arís.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Bhí fadhb ann agus tú ag iarraidh an focal faire a athshocrú, déan iarracht arís.',
        'success' => 'D\'athshocraigh do phasfhocal go rathúil.',
    ),


);
